#!/usr/bin/python
## This is an example of a simple sound capture script.
##
## The script opens an ALSA pcm for sound capture. Set
## various attributes of the capture, and reads in a loop,
## Then prints the volume.
##
## To test it out, run it and shout at your microphone:

import alsaaudio, time, audioop, subprocess, logging

logger = logging.getLogger('audio_display_control')
hdlr = logging.FileHandler('./audio_display_control.log')
formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
hdlr.setFormatter(formatter)
logger.addHandler(hdlr) 
logger.setLevel(logging.INFO)

# Open the device in nonblocking capture mode. The last argument could
# just as well have been zero for blocking mode. Then we could have
# left out the sleep call in the bottom of the loop
inp = alsaaudio.PCM(alsaaudio.PCM_CAPTURE,alsaaudio.PCM_NONBLOCK)

# Set attributes: Mono, 8000 Hz, 16 bit little endian samples
inp.setchannels(1)
inp.setrate(8000)
inp.setformat(alsaaudio.PCM_FORMAT_S16_LE)

# The period size controls the internal number of frames per period.
# The significance of this parameter is documented in the ALSA api.
# For our purposes, it is suficcient to know that reads from the device
# will return this many frames. Each frame being 2 bytes long.
# This means that the reads below will return either 320 bytes of data
# or 0 bytes of data. The latter is possible because we are in nonblocking
# mode.
inp.setperiodsize(160)

avg = 0
c = 0
precision = 100
threshold = 100
awake = True
last_wake = time.time()
stayontime = 120
logger.info('starting audio display control with threshold ' + str(threshold))
while True:
    # Read data from device
    l,data = inp.read()
    if l:
        # Return the maximum of the absolute value of all samples in a fragment.
        #print audioop.max(data, 2)
	avg += audioop.max(data, 2)
	c = c + 1
	if (c >= precision/5):
	    avg = avg / c
	    c = 0
	    # print avg
	    now = time.time()
            if avg > threshold:
		#logger.info(avg)
		#print 1
                last_wake = now
                if awake == False:
                    awake = True
		    logger.info("turning on display, amplitude was " + str(avg))
                    subprocess.call(['bash', '/home/pi/monitor_wake.sh'])
            else:
		#print 2
                if awake:
                    now = time.time()
                    if now - last_wake > stayontime:
                        subprocess.call(['bash', '/home/pi/monitor_sleep.sh'])
			logger.info("turning off display")
                        awake = False
                        last_sleep = now
    time.sleep(1/precision)
